
function[t1,E]=mytest()
    % mytest: Function to test the performance of the custom n_svd function
    % Outputs:
    %   t1 - Total time taken to perform SVD on multiple matrices.
    %   E - Frobenius norm of the reconstruction error for the last matrix.

    % Start profiling to analyze performance
    profile on

    % Load test data from 'test.mat'
    load('test.mat')  % Assumes 'test.mat' contains matrices A0, A1, ..., A5

    % Initial call to n_svd for warming up (results not stored)
    [U,S,V] = n_svd(A0);

    % Start the timer to measure performance
    tic

    % Perform SVD on multiple matrices using the custom n_svd function
    [U,S,V] = n_svd(A1);
    [U,S,V] = n_svd(A2);
    [U,S,V] = n_svd(A3);
    [U,S,V] = n_svd(A4);
    [U,S,V] = n_svd(A5);

    % Stop the timer and store the elapsed time
    t1 = toc;

    % Calculate the reconstruction error for the last matrix A5
    res = A5 - U*S*V';

    % Calculate the Frobenius norm of the reconstruction error
    E = norm(res, 'fro');

    % Open the profile viewer to analyze the performance details
    profile viewer
end

