function [U,S,V]=n_svd(A)
    % n_svd: Custom function to perform Singular Value Decomposition (SVD)
    % Input:
    %   A - Input matrix on which SVD is to be performed. 
    %       If no input is given, a random matrix is generated.
    % Output:
    %   U, S, V - Matrices resulting from the SVD of matrix A.

    % Check if any input is given
    if nargin==0
        % If no input is provided, generate a random 100x70 matrix
        R = rand(100,70);

        % Perform SVD on the random matrix
        [U,S,V] = n_svd(R);

        % Calculate the reconstruction error (not used further)
        res = R - U*S*V';

        % End the function here if no input was initially provided
        return
    end

    % Perform a custom transformation/preprocessing on A
    [U,A,V] = new_TSB(A);

    % Get the size of the transformed matrix
    [m,n] = size(A);

    % Adjust matrix A to be a square matrix of size n if m > n
    A = A(1:n,:);

    % Perform another custom SVD on the adjusted matrix A
    [u,S,v] = ouyang_SVD(A);

    % If the original matrix had more rows than columns,
    % pad the u matrix with zeros at the bottom
    u(n+1:m,:) = 0;

    % Update U and V matrices
    U = U * u;
    V = V' * v;
end
