# Enhanced SVD Computation Toolkit

## Introduction

This toolkit, developed by Jiasheng Xu and Yuxiang Tong under the guidance of Professor Zhu Shengxin and with inputs from classmates in the numerical algebra course, optimizes and expedites the process of Singular Value Decomposition (SVD) for matrices. It introduces innovative algorithms and matrix transformations to enhance the efficiency of SVD operations.

## Features

- **Optimized SVD Algorithm (`n_svd`)**: Custom implementation of the SVD algorithm tailored for improved performance.
- **Efficient Matrix Transformation (`new_TSB` and `qr_givens`)**: Implements advanced matrix transformation techniques for faster SVD computation.
- **Performance Testing (`mytest`)**: Function to evaluate the performance of the SVD computation, measuring execution time and accuracy.
- **Customizable Matrix Input**: Users can modify and use their own matrices by replacing the `test.mat` file.

## Getting Started

### Prerequisites

- MATLAB installed on your system.

### Running the Toolkit

1. **Performance Testing**:
   - Run the `mytest` function to measure the performance of the SVD process. It times the computation and calculates the reconstruction error.

2. **Performing SVD**:
   - Use the `n_svd` function to perform singular value decomposition on your matrix. This function returns matrices U, Σ, and V.

3. **Custom Matrix Input**:
   - Replace the `test.mat` file with your own matrix file in MATLAB's `.mat` format, containing matrices as per the existing code's requirements.

### Example

```matlab
% Load your custom matrix
load('your_matrix_file.mat'); % Replace 'your_matrix_file.mat' with your file name

% Perform SVD
[U, S, V] = n_svd(your_matrix);

% Measure performance
[time, error] = mytest();
